package com.nemrodsoftware;

import java.io.File;
import java.io.IOException;
import java.util.List;

import com.nemrodsoftware.model.Locale;
import com.nemrodsoftware.model.Module;
import com.nemrodsoftware.model.Project;

public interface INemrodClient
{
    /**
     * Try to log in to Nemrod
     * 
     * @return true if logged, false otherwise
     */
    public abstract boolean login();

    /**
     * Find a project by name
     * 
     * @param projectName
     * @return the project or null if not found
     */
    public abstract Project findProject(String projectName);

    /**
     * @return the list of all visible projects for your profile
     */
    public abstract List<Project> listProject();

    /**
     * @param project
     * @return the list of all locales available for this project
     */
    public abstract List<Locale> listLocale(Project project);

    /**
     * @param project
     * @param localeName
     * @return the locale with the same for this project or null if not found
     */
    public abstract Locale findLocale(Project project, String localeName);

    /**
     * @param project
     * @return the list of modules for this project
     */
    public abstract List<Module> listModule(Project project);

    /**
     * @param project
     * @param moduleName
     * @param modulePath
     * @return the module with the given name or null if not found 
     */
    public abstract Module findModule(Project project, String moduleName, String modulePath);

    /**
     * @param project
     * @param locale
     * @param module
     * @param exportType
     * @param exportEmptyValues
     * @param exportOnlyApprovedValues
     * @param workFolder
     * @return a file descriptor on the downloaded file
     * @throws IOException if an error occured when downloading the file
     */
    public abstract File export(Project project, Locale locale, Module module, String exportType, boolean exportEmptyValues, boolean exportOnlyApprovedValues, String workFolder) throws IOException;

    /**
     * @param project
     * @param format
     * @param module
     * @param modulePath
     * @param masterFile
     */
    public abstract boolean sync(Project project, String format, Module module, File masterFile);

}